@@ -1,6 +1,6 @@
 package App::RecordStream::Operation::toprettyprint;
 
-our $VERSION = "4.0.14";
+our $VERSION = "4.0.15";
 
 use strict;
 
@@ -17,11 +17,12 @@ sub init {
   my $key_groups  = App::RecordStream::KeyGroups->new();
   my $do_not_nest = 0;
   my $spec = {
-    "1"        => sub { $limit = 1; },
-    "one"      => sub { $limit = 1; },
-    "n=i"      => \$limit,
-    'keys|k=s' => sub { $key_groups->add_groups($_[1]); },
-    'nonested' => \$do_not_nest,
+    "1"         => sub { $limit = 1; },
+    "one"       => sub { $limit = 1; },
+    "n=i"       => \$limit,
+    'keys|k=s'  => sub { $key_groups->add_groups($_[1]); },
+    'nonested'  => \$do_not_nest,
+    'aligned:s' => \(my $aligned),
   };
 
   $this->parse_options($args, $spec);
@@ -33,6 +34,8 @@ sub init {
   $this->{'LIMIT'}         = $limit;
   $this->{'KEY_GROUPS'}    = $key_groups;
   $this->{'NESTED_OUTPUT'} = not $do_not_nest;
+  $this->{'ALIGNED'}       = $aligned =~ /^l(eft)?$/i ? 'left' : 'right'
+    if defined $aligned;
 };
 
 sub accept_record {
@@ -49,6 +52,16 @@ sub accept_record {
 
   my $specs = $this->{'KEY_GROUPS'}->get_keyspecs_for_record($record);
 
+  if ($this->{'ALIGNED'}) {
+    for my $key (@$specs) {
+      my $width = length $key;
+      $this->{'FORMAT_KEY_WIDTH'} = $width
+        if $width > $this->{'FORMAT_KEY_WIDTH'};
+    }
+    $this->{'FORMAT_KEY_WIDTH'} *= -1
+      if $this->{'ALIGNED'} eq 'left';
+  }
+
   $this->push_line('-' x 70);
   foreach my $key (sort @$specs) {
     my $value = ${$record->guess_key_from_spec($key)};
@@ -58,12 +71,21 @@ sub accept_record {
   return 1;
 }
 
+sub _format_key {
+  my $this = shift;
+  my $key  = shift;
+  return $key unless $this->{'FORMAT_KEY_WIDTH'};
+  return sprintf '%*s', $this->{'FORMAT_KEY_WIDTH'}, $key;
+}
+
 sub output_value {
   my $this   = shift;
   my $prefix = shift;
   my $key    = shift;
   my $value  = shift;
 
+  $key = $this->_format_key($key);
+
   if ( (ref($value) eq 'HASH') &&  $this->{'NESTED_OUTPUT'} ) {
     if ( scalar keys %$value > 0 ) {
       $this->push_line($prefix . "$key = HASH:");
@@ -126,6 +148,7 @@ sub usage {
     ['keys', 'Only print out specified keys, Maybe keyspecs may be keygroups, see --help-keys for more information'],
     ['nonested', 'Do not nest the output of hashes, keep each value on one line'],
     ['n <n>', 'Only print n records'],
+    ['aligned [r|l|right|left]', 'Format keys to the same width so values are aligned.  Keys are right aligned by default, but you may pass a value of "left" to left align keys within the width.'],
   ];
 
   my $args_string = $this->options_string($options);
