@@ -150,7 +150,7 @@ records.
 
 =cut
 
-our $VERSION = "4.0.14";
+our $VERSION = "4.0.15";
 
 use strict;
 use warnings;
@@ -272,7 +272,7 @@ sub sort
   my $records = shift;
   my @specs   = @_;
 
-  return CORE::sort { $a->cmp($b, @specs) } @$records;
+  return map { $records->[$_] } CORE::sort { $records->[$a]->cmp($records->[$b], @specs) || ($a <=> $b) } (0..(@$records - 1));
 }
 
 ### Actual class
